@@ -14,6 +14,7 @@ legendBreaks = function(pos,
     inset=0.05,
     title.col=text.col,
     adj=0,
+		width=Inf, lines=Inf,
     y.intersp,
     ...){
 
@@ -60,6 +61,7 @@ legendBreaks = function(pos,
     legend=rev(legend)
   }
   
+	diffYmult = 0
   if(length(col) == (length(legend)-1)) {
     # one more legend item than colours
     col = c(NA, col)
@@ -78,24 +80,43 @@ legendBreaks = function(pos,
     }
   }
   
-
-if(missing(y.intersp)){
-  y.intersp = gregexpr("\n", 
-              as.character(legend)
-          )
-y.intersp=max(
-    unlist(lapply(y.intersp, function(qq) sum(qq>0)))
-)
-if(all(is.na(y.intersp))){
-  y.intersp=0
-}
-if(y.intersp>0){
-  y.intersp = 1.5
-} else {
-  y.intersp=1
-}
-} 
-
+# line wrapping for legend labels
+	if(any(nchar(as.character(legend)) > width)) {
+		legend =  trim(
+  	  	gsub(
+    			paste('(.{1,', width, '})(\\s|/|$)' ,sep=''), 
+					'\\1\n ', 
+    			as.character(legend)
+				)
+		)
+	}
+	
+	# remove excess lines
+	theNewLines = gregexpr('\n', as.character(legend))
+	toCrop = which(unlist(lapply(theNewLines, length)) >= lines)
+	if(length(toCrop)) {
+		cropPos = unlist(lapply(theNewLines[toCrop], function(qq) qq[lines]))
+		legend = as.character(legend)
+		legend[toCrop] = 
+			trim(substr(legend[toCrop], 1, cropPos))
+	}
+	
+	if(missing(y.intersp)){
+		
+		if(is.character(legend)) {	
+			theNewLines = gregexpr('\n', as.character(legend))
+			y.intersp=max(
+    		c(0.5, unlist(lapply(theNewLines, function(qq) sum(qq>0))))
+			) - 0.25
+		} else {
+			y.intersp = 1
+		}
+	}
+	if(all(is.na(y.intersp))){
+  	y.intersp=0
+	}
+	adj = rep_len(adj, 2)
+	adj[2] = adj[2] + y.intersp/3
 
   # get rid of transparency in col
   withTrans = grep("^#[[:xdigit:]]{8}$", col)
@@ -137,6 +158,7 @@ if(y.intersp>0){
       title.col=title.col,
       title=title,
       y.intersp=y.intersp,
+			adj=adj,
       ...
       )
       
@@ -152,101 +174,9 @@ if(y.intersp>0){
       
       
       text(result$text$x, result$text$y,
-          legend, col=text.col,adj=adj)   
+          legend, col=text.col,adj=adj, cex=cex)   
     }      
       par(xpd=oldxpd)
       
       return(invisible(result))
 }
-
-legendBreaksOld = function(pos, breaks, outer=TRUE,...){
-	ldots = list(...)
-
-	defaults = list(pch=15,  x=pos,bg="white",
-		inset=0.001,cex=1)
-	
-if(outer){
-	oldxpd = par("xpd")
-	par(xpd=NA)
-	fromEdge = matrix(par("plt"), 2, 2, 
-			dimnames=list(c("min","max"), c("x","y")))
-	propIn = apply(fromEdge, 2, diff)
-	if(is.character(pos)) {
-		inset = c(0,0)
-#		if(length(grep("^bottom", pos))){
-#			inset[2] = -fromEdge["min","y"]					
-#		} else if(length(grep("^top", pos))){
-#			inset[2] = fromEdge["max","y"]-1					
-#		}
-		
-		if(length(grep("left$", pos))){
-			inset[1] = -fromEdge["min","x"]					
-		} else if(length(grep("right$", pos))){
-			inset[1] = fromEdge["max","x"]-1					
-		}
-		inset = inset/propIn
-		defaults$inset = inset+ 0.01
-	}
-} else {
-	defaults$inset = 0.01
-}
-
-
-	if(is.list(breaks)){
-		if(length(breaks$col) ) {
-			ldots$col=breaks$col
-		}
-		if( length(breaks$breaks)) {
-			breaks=breaks$breaks
-		}
-	}
-
-	
-	
-	for(D in names(defaults))
-		if(is.null(ldots[[D]]))
-			ldots[[D]] = defaults[[D]]
-	
-	defaults = list(pt.cex=2.5*ldots[["cex"]])
-	for(D in names(defaults))
-		if(is.null(ldots[[D]]))
-			ldots[[D]] = defaults[[D]]
-	
-	
-	ldots$legend = rev(breaks)
-	ldots$col = rev(ldots$col)
-	
-	
-	# get rid of transparency in col
-	withTrans = grep("^#[[:xdigit:]]{8}$", ldots$col)
-	ldots$col[withTrans] = gsub("[[:xdigit:]]{2}$", "", ldots$col)
-	
-	if(length(breaks)-1 == length(ldots$col)) {
-		ltext = format(ldots$legend,
-				width=max(nchar(ldots$legend)))
-		ldots$col = c(NA, ldots$col)
-		ldots$legend = rep(NA, length(ldots$col))
-		ldots$text.width = max(strwidth(ltext))
-	} 
-	
-	result=do.call(legend, ldots)
- 
-	
-	if(all(is.na(ldots$legend))) {
-		x=ldots
-		if(!is.null(x$title))
-			x$title = NA
-		x$legend=ltext
-		x$x = result$rect$left
-		x$y = result$rect$top - 0.75*par("cxy")[2]
-		x$adj = c(-0.2, 0) 
-		x$col=NA
-		x$bty='n'
- 
-		do.call(legend,x)
-	}
-
-	par(xpd=oldxpd)
-	
-	return(invisible(result))
-}
